import unittest
from redzoo.math.display import duration
from datetime import datetime, timedelta



class DisplayTest(unittest.TestCase):

    def test_int(self):
        print(duration(66.8))

    def test_timedelta(self):
        yesterday = datetime.now() - timedelta(days=1)
        today = datetime.now()
        print(duration(today-yesterday))


if __name__ == '__main__':
    unittest.main()


from datetime import timedelta




def duration(elapsed_seconds, digits: int = 0) -> str:
    if isinstance(elapsed_seconds, timedelta):
        elapsed_seconds = elapsed_seconds.total_seconds()

    if elapsed_seconds > 60 * 60:
        hours = round(elapsed_seconds / (60 * 60), digits)
        return str(hours if digits>0 else int(hours)) + " hour"
    elif elapsed_seconds > 60:
        minutes = round(elapsed_seconds / 60, digits)
        return str(minutes if digits>0 else int(minutes)) + " min"
    else:
        seconds = round(elapsed_seconds, digits)
        return str(seconds if digits>0 else int(seconds)) + " sec"


import unittest
from time import sleep
from redzoo.database.simple import SimpleDB



class SimpleDbTest(unittest.TestCase):

    def test_db(self):
        db = SimpleDB("test")
        db.put("1", 5)
        db.put("2", 8)
        self.assertIs(5, db.get("1"))
        self.assertIs(5, sorted(db.get_values())[0])
        self.assertIs(8, sorted(db.get_values())[1])

        db.clear()
        self.assertIs(0, len(db))

        db.put("3", 9, ttl_sec=1)
        db.put("4", 55, ttl_sec=1000000000)
        self.assertIs(9, db.get("3"))
        self.assertIs(55, db.get("4"))
        sleep(1.5)
        self.assertIsNone(db.get("3"))
        self.assertIs(88, db.get("3", 88))
        self.assertIs(55, db.get("4"))


    def test_db_persistence(self):
        db = SimpleDB("test2")
        db.clear()
        db.put("1", 5)
        self.assertIs(5, db.get("1"))

        db = SimpleDB("test2")
        self.assertIs(5, db.get("1"))

if __name__ == '__main__':
    unittest.main()